<?php
/**
 * Simple Machines Forum (SMF)
 *
 * @package SMF
 * @author Simple Machines https://www.simplemachines.org
 * @copyright 2022 Simple Machines and individual contributors
 * @license https://www.simplemachines.org/about/smf/license.php BSD
 *
 * @version 2.1.3
 */

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	https://www.simplemachines.org/
*/

/**
 * Initialize the template... mainly little settings.
 */
function template_init()
{
	global $settings, $txt;
	loadCSSFile('font-awesome.min.css');
    loadCSSFile('all.css');
	$settings['theme_variants'] = array('default', 'blue', 'black', 'burgundy', 'yellow');

	/* $context, $options and $txt may be available for use, but may not be fully populated yet. */

	// The version this template/theme is for. This should probably be the version of SMF it was created for.
	$settings['theme_version'] = '2.1';

	// Set the following variable to true if this theme requires the optional theme strings file to be loaded.
	$settings['require_theme_strings'] = true;

	// Set the following variable to true if this theme wants to display the avatar of the user that posted the last and the first post on the message index and recent pages.
	$settings['avatars_on_indexes'] = false;

	// Set the following variable to true if this theme wants to display the avatar of the user that posted the last post on the board index.
	$settings['avatars_on_boardIndex'] = true;

	// Set the following variable to true if this theme wants to display the login and register buttons in the main forum menu.
	$settings['login_main_menu'] = false;

	// This defines the formatting for the page indexes used throughout the forum.
	$settings['page_index'] = array(
		'extra_before' => '<span class="pages">' . $txt['pages'] . '</span>',
		'previous_page' => '<span class="main_icons previous_page"></span>',
		'current_page' => '<span class="current_page">%1$d</span> ',
		'page' => '<a class="nav_page" href="{URL}">%2$s</a> ',
		'expand_pages' => '<span class="expand_pages" onclick="expandPages(this, {LINK}, {FIRST_PAGE}, {LAST_PAGE}, {PER_PAGE});"> ... </span>',
		'next_page' => '<span class="main_icons next_page"></span>',
		'extra_after' => '',
	);

	// Allow css/js files to be disabled for this specific theme.
	// Add the identifier as an array key. IE array('smf_script'); Some external files might not add identifiers, on those cases SMF uses its filename as reference.
	if (!isset($settings['disable_files']))
		$settings['disable_files'] = array();
}

/**
 * The main sub template above the content.
 */
function template_html_above()
{
	global $context, $scripturl, $txt, $modSettings;

	// Show right to left, the language code, and the character set for ease of translating.
	echo '<!DOCTYPE html>
<html', $context['right_to_left'] ? ' dir="rtl"' : '', !empty($txt['lang_locale']) ? ' lang="' . str_replace("_", "-", substr($txt['lang_locale'], 0, strcspn($txt['lang_locale'], "."))) . '"' : '', '>
<head>
	<meta charset="', $context['character_set'], '">';

	/*
		You don't need to manually load index.css, this will be set up for you.
		Note that RTL will also be loaded for you.
		To load other CSS and JS files you should use the functions
		loadCSSFile() and loadJavaScriptFile() respectively.
		This approach will let you take advantage of SMF's automatic CSS
		minimization and other benefits. You can, of course, manually add any
		other files you want after template_css() has been run.

	*	Short example:
			- CSS: loadCSSFile('filename.css', array('minimize' => true));
			- JS:  loadJavaScriptFile('filename.js', array('minimize' => true));
			You can also read more detailed usages of the parameters for these
			functions on the SMF wiki.

	*	Themes:
			The most efficient way of writing multi themes is to use a master
			index.css plus variant.css files. If you've set them up properly
			(through $settings['theme_variants']), the variant files will be loaded
			for you automatically.
			Additionally, tweaking the CSS for the editor requires you to include
			a custom 'jquery.sceditor.theme.css' file in the css folder if you need it.

	*	MODs:
			If you want to load CSS or JS files in here, the best way is to use the
			'integrate_load_theme' hook for adding multiple files, or using
			'integrate_pre_css_output', 'integrate_pre_javascript_output' for a single file.
	*/

	// load in any css from mods or themes so they can overwrite if wanted
	template_css();

	// load in any javascript files from mods and themes
	template_javascript();

	echo '
	<title>', $context['page_title_html_safe'], '</title>
	<meta name="viewport" content="width=device-width, initial-scale=1">';

	// Content related meta tags, like description, keywords, Open Graph stuff, etc...
	foreach ($context['meta_tags'] as $meta_tag)
	{
		echo '
	<meta';

		foreach ($meta_tag as $meta_key => $meta_value)
			echo ' ', $meta_key, '="', $meta_value, '"';

		echo '>';
	}

	/*	What is your Lollipop's color?
		Theme Authors, you can change the color here to make sure your theme's main color gets visible on tab */
	echo '
	<meta name="theme-color" content="#407a91cc">';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex">';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '">';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help">
	<link rel="contents" href="', $scripturl, '">', ($context['allow_search'] ? '
	<link rel="search" href="' . $scripturl . '?action=search">' : '');

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?action=.xml;type=rss2', !empty($context['current_board']) ? ';board=' . $context['current_board'] : '', '">
	<link rel="alternate" type="application/atom+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['atom'], '" href="', $scripturl, '?action=.xml;type=atom', !empty($context['current_board']) ? ';board=' . $context['current_board'] : '', '">';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['links']['next']))
		echo '
	<link rel="next" href="', $context['links']['next'], '">';

	if (!empty($context['links']['prev']))
		echo '
	<link rel="prev" href="', $context['links']['prev'], '">';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0">';

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];

	echo '
</head>
<body id="', $context['browser_body_id'], '" class="action_', !empty($context['current_action']) ? $context['current_action'] : (!empty($context['current_board']) ?
		'messageindex' : (!empty($context['current_topic']) ? 'display' : 'home')), !empty($context['current_board']) ? ' board_' . $context['current_board'] : '', '">
<div id="footerfix">';
}
/**
 * The upper part of the main template layer. This is the stuff that shows above the main forum content.
 */
function template_body_above()
{
	global $context, $settings, $scripturl, $txt, $modSettings, $maintenance;

	// Wrapper div now echoes permanently for better layout options. h1 a is now target for "Go up" links.
	echo '
	<div id="top_section">
		<div class="inner_wrap">';
	// If the user is logged in, display some things that might be useful.
	if ($context['user']['is_logged'])
	{
		// Firstly, the user's menu
		echo '
			<ul class="floatleft" id="top_info">
				<li>
					<a href="', $scripturl, '?action=profile"', !empty($context['self_profile']) ? ' class="active"' : '', ' id="profile_menu_top">';

		if (!empty($context['user']['avatar']))
			echo $context['user']['avatar']['image'];

		echo '<span class="textmenu">', $context['user']['name'], '</span></a>
					<div id="profile_menu" class="top_menu"></div>
				</li>';

		// Secondly, PMs if we're doing them
		if ($context['allow_pm'])
			echo '
				<li>
					<a href="', $scripturl, '?action=pm"', !empty($context['self_pm']) ? ' class="active"' : '', ' id="pm_menu_top">
						<i class="fa-solid fa-envelope"></i><span class="main_icons inbox"></span>
						<span class="textmenu">', $txt['pm_short'], '</span>', !empty($context['user']['unread_messages']) ? '
						<span class="amt" style="-webkit-animation: pulse3 linear 1000ms infinite;">' . $context['user']['unread_messages'] . '</span>' : '', '
					</a>
					<div id="pm_menu" class="top_menu scrollable"></div>
				</li>';

		// Thirdly, alerts
		echo '
				<li>
					<a href="', $scripturl, '?action=profile;area=showalerts;u=', $context['user']['id'], '"', !empty($context['self_alerts']) ? ' class="active"' : '', ' id="alerts_menu_top">
						<i class="fa-solid fa-bell"></i><span class="main_icons alerts"></span>
						<span class="textmenu">', $txt['alerts'], '</span>', !empty($context['user']['alerts']) ? '
						<span class="amt" style="-webkit-animation: pulse3 linear 1000ms infinite;">' . $context['user']['alerts'] . '</span>' : '', '
					</a>
					<div id="alerts_menu" class="top_menu scrollable"></div>
				</li>';

		// A logout button for people without JavaScript.
		if (empty($settings['login_main_menu']))
			echo '
				<li id="nojs_logout">
					<a href="', $scripturl, '?action=logout;', $context['session_var'], '=', $context['session_id'], '">', $txt['logout'], '</a>
					<script>document.getElementById("nojs_logout").style.display = "none";</script>
				</li>';

		// And now we're done.
		echo '
			</ul>';
	}
	// Otherwise they're a guest. Ask them to either register or login.
	elseif (empty($maintenance))
	{
		// Some people like to do things the old-fashioned way.
		if (!empty($settings['login_main_menu']))
		{
			echo '
			<ul class="floatleft">
				<li class="welcome">', sprintf($txt[$context['can_register'] ? 'welcome_guest_register' : 'welcome_guest'], $context['forum_name_html_safe'], $scripturl . '?action=login', 'return reqOverlayDiv(this.href, ' . JavaScriptEscape($txt['login']) . ', \'login\');', $scripturl . '?action=signup'), '</li>
			</ul>';
		}
		else
		{
			echo '
			<ul class="floatleft" id="top_info">
				<li class="welcome">
					', sprintf($txt['welcome_to_forum'], $context['forum_name_html_safe']), '
				</li>
				<li class="button_login">
					<a href="', $scripturl, '?action=login" class="', $context['current_action'] == 'login' ? 'active' : 'open','" onclick="return reqOverlayDiv(this.href, ' . JavaScriptEscape($txt['login']) . ', \'login\');">
						<span class="main_icons login"></span>
						<span class="textmenu">', $txt['login'], '</span>
					</a>
				</li>';

			if ($context['can_register'])
				echo '
				<li class="button_signup">
					<a href="', $scripturl, '?action=signup" class="', $context['current_action'] == 'signup' ? 'active' : 'open','">
						<span class="main_icons regcenter"></span>
						<span class="textmenu">', $txt['register'], '</span>
					</a>
				</li>';

			echo '
			</ul>';
		}
	}
	else
		// In maintenance mode, only login is allowed and don't show OverlayDiv
		echo '
			<ul class="floatleft welcome">
				<li>', sprintf($txt['welcome_guest'], $context['forum_name_html_safe'], $scripturl . '?action=login', 'return true;'), '</li>
			</ul>';

	if (!empty($modSettings['userLanguage']) && !empty($context['languages']) && count($context['languages']) > 1)
	{
		echo '
			<form id="languages_form" method="get" class="floatright">
				<select id="language_select" name="language" onchange="this.form.submit()">';

		foreach ($context['languages'] as $language)
			echo '
					<option value="', $language['filename'], '"', isset($context['user']['language']) && $context['user']['language'] == $language['filename'] ? ' selected="selected"' : '', '>', str_replace('-utf8', '', $language['name']), '</option>';

		echo '
				</select>
				<noscript>
					<input type="submit" value="', $txt['quick_mod_go'], '">
				</noscript>
			</form>';
	}
   echo '
	<ul class="p-nav-opposite floatright">
    <li class="custom-control custom-switch">
            <input type="checkbox" class="custom-control-input" id="darkSwitch">
            <label class="custom-control-label" for="darkSwitch"></label>
          </li>
        </ul>';
	if ($context['allow_search'])
	{
		echo '
			<form id="search_form" class="floatright" action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
				<input type="search" name="search" value="">&nbsp;';

		// Using the quick search dropdown?
		$selected = !empty($context['current_topic']) ? 'current_topic' : (!empty($context['current_board']) ? 'current_board' : 'all');

		echo '
				<select name="search_selection">
					<option value="all"', ($selected == 'all' ? ' selected' : ''), '>', $txt['search_entireforum'], ' </option>';

		// Can't limit it to a specific topic if we are not in one
		if (!empty($context['current_topic']))
			echo '
					<option value="topic"', ($selected == 'current_topic' ? ' selected' : ''), '>', $txt['search_thistopic'], '</option>';

		// Can't limit it to a specific board if we are not in one
		if (!empty($context['current_board']))
			echo '
					<option value="board"', ($selected == 'current_board' ? ' selected' : ''), '>', $txt['search_thisboard'], '</option>';

		// Can't search for members if we can't see the memberlist
		if (!empty($context['allow_memberlist']))
			echo '
					<option value="members"', ($selected == 'members' ? ' selected' : ''), '>', $txt['search_members'], ' </option>';

		echo '
				</select>';

		// Search within current topic?
		if (!empty($context['current_topic']))
			echo '
				<input type="hidden" name="sd_topic" value="', $context['current_topic'], '">';

		// If we're on a certain board, limit it to this board ;).
		elseif (!empty($context['current_board']))
			echo '
				<input type="hidden" name="sd_brd" value="', $context['current_board'], '">';

		echo '
				<input type="submit" name="search2" value="', $txt['search'], '" class="button">
				<input type="hidden" name="advanced" value="0">
			</form>';
	}

	echo '
		</div><!-- .inner_wrap -->
	     <!-- #top_section -->';

    echo '
           </div>
          <div id="wrapper">
		  <div class="frame">';		    

	  if (!empty($settings['custom_title']) && $settings['custom_title'] == 'logo')
    {
		$teknoromibanner = array( 
			1=>''. $settings['logo_resimadres'].' ',	
			2=>''. $settings['logo_resimadres1'].' ',
			3=>''. $settings['logo_resimadres2'].' '
						);
				$sayı = count($teknoromibanner);
				$degiş = rand(1,$sayı);
				
		echo '<div class="logomhide"><a href="'. $settings['logo_link'].'" title=" '. $settings['title_logoanahtarkelime']. '"><img class="sitelogo" alt="' . $context['forum_name'] . '" src="'.$teknoromibanner[$degiş].'"></a></div>';	              
			 if (!empty($settings['logo_balon']))
			{
			echo '
			  <div class="damla"><svg viewBox="0 0 120 28" style="margin: -100px;">
                <circle class="drop drop1" cx="142" cy="2" r="1.8"/>
				<circle class="drop drop1" cx="126" cy="2" r="1.8"/>
                <circle class="drop drop2" cx="112" cy="2.5" r="2.4"/>
                <circle class="drop drop3" cx="98" cy="2.1" r="2.4"/>
				<circle class="drop drop2" cx="84" cy="2.1" r="2.5"/>
				<circle class="drop drop3" cx="70" cy="2.1" r="2.4"/>
				<circle class="drop drop2" cx="56" cy="2.1" r="2.6"/>
				<circle class="drop drop3" cx="42" cy="2.1" r="2.3"/>
				<circle class="drop drop2" cx="28" cy="2.1" r="2.1"/></svg></div>'; 
				}
			echo '
             <div class="headerBlok--dalga dalgaIcerik _dalgaYonlendir "> 
			<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 2000 260" preserveAspectRatio="none"> 	
				<defs>
					<linearGradient id="xgtDalgaGranit">
					<stop offset="0%" stop-color="var(--xgtDalgaRenk1)"></stop>
					<stop offset="50%" stop-color="var(--xgtDalgaRenk2)"></stop>
					<stop offset="100%" stop-color="var(--xgtDalgaRenk3)"></stop>
					</linearGradient>
				</defs>
				<path fill="url(#xgtDalgaGranit)" d="M-42,42c21.03-0.71,49.03-1.3,82-1c10.06,0.09,73,0.78,147,7c95.4,8.01,191.25,23.7,278,40 c188.62,35.43,247.14,57.2,353,79c102.08,21.02,252.74,44.36,445,46c0,22.68,0,45.35,0,68.03c-433.33,0-866.67,0-1300,0 C-38.67,201.35-40.33,121.68-42,42z"></path>
				<path d="M-39,233c18.45-5.57,45.76-13.68,79-23c65.89-18.48,100.28-28.12,140-36c64.67-12.83,115.09-15.35,151-17 c72.37-3.33,126.81,0.97,200,7c21.78,1.79,35.05,3.15,147,16c185.79,21.33,205.66,24.08,252,27c85.5,5.38,150.46,4.35,168,4 c48.7-0.96,73.47-3.33,246-19c174.43-15.84,185.89-16.75,211-18c76.46-3.81,133.48-3.48,217-3c83.26,0.48,125.58,2.59,166,6 c37.33,3.15,68.3,7,90,10c0,28.67,0,57.35,0,86.02c-688.33,0-1376.67,0-2065,0C-37.67,259.68-38.33,246.34-39,233z"></path> 	
			</svg></div>	
			<br><h1 class="forumtitle1"><a class="mobile_user_menu">
          <span class="menu_icon"></span><span class="text_menu">', $txt['mobile_user_menu'], '</span></a>
			<a id="top" href="', $scripturl, '">', empty($context['header_logo_url_html_safe']) ? $context['forum_name'] : '<img src="' . $context['header_logo_url_html_safe'] . '" alt="' . $context['forum_name'] . '">', '</a>
			 </h1>'; 
			 }
			  echo' </div>	
              <div id="main_menu" class="sticky-top smopen">
               <div id="mobile_user_menu" class="popup_container">			
                <div class="popup_window description">				  
                <div class="popup_heading">', $txt['mobile_user_menu'], '			
                  <a href="javascript:void(0);" class="main_icons hide_popup"></a>
                  </div> ', template_menu(), '           
                   </div>
                     </div>
                       </div>						
		<div id="upper_section">
			<div id="inner_section">
				<div id="inner_wrap"', !$context['user']['is_logged'] ? ' class="hide_720"' : '', '>
					<div class="user">
						<time datetime="', smf_gmstrftime('%FT%TZ'), '">', $context['current_time'], '</time>';
	if ($context['user']['is_logged'])
		echo '
						<ul class="unread_links">
							<li>
								<a href="', $scripturl, '?action=unread" title="', $txt['unread_since_visit'], '">', $txt['view_unread_category'], '</a>
							</li>
							<li>
								<a href="', $scripturl, '?action=unreadreplies" title="', $txt['show_unread_replies'], '">', $txt['unread_replies'], '</a>
							</li>
						</ul>';

	echo '
					</div>';
 
	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']) && !empty($context['random_news_line']))
		echo '
					<div class="news">
						<h2>', $txt['news'], ': </h2>
						<p>', $context['random_news_line'], '</p>
					</div>';

	echo '
				</div>';

	// Show the menu here, according to the menu sub template, followed by the navigation tree.
    // Load mobile menu here
	echo '<div id="header">';
	if (!empty($settings['custom_title']) && $settings['custom_title'] == 'logo')
    {

	echo '
	       </div>';
	echo '
          <div class="p-title-pageAction">
                 <a href="', $scripturl, '?action=unread" class="button button--icon button--icon--bolt" title="', $txt['unread_since_visit'], '"><i class="fas fa-robot"></i><br><span class="button-text">', $txt['view_unread_category'], '</span></a>
                 <a href="', $scripturl, '?action=post" class="button--cta button button--icon button--icon--write" title="', $txt['new_topic'], '"><i class="fas fa-feather-alt"></i><br><span class="button-text">', $txt['new_topic'], '</span></a>
                  </div>';
	}
	if (!empty($settings['custom_title']) && $settings['custom_title'] == 'title')
    {
	echo '	
	<h1 class="forumtitle"><a class="mobile_user_menu">
					<span class="menu_icon"></span>
					<span class="text_menu">', $txt['mobile_user_menu'], '</span>
				</a>
		<a id="top" href="', $scripturl, '">', empty($context['header_logo_url_html_safe']) ? $context['forum_name_html_safe'] : '<img src="' . $context['header_logo_url_html_safe'] . '" alt="' . $context['forum_name_html_safe'] . '">', '</a>
		 </h1>', empty($settings['site_slogan']) ? '<img id="smflogo" src="' . $settings['images_url'] . '/smflogo.svg" alt="Simple Machines Forum" title="Simple Machines Forum">' : '<div id="siteslogan" class="floatright">' . $settings['site_slogan'] . '</div>', '</div>	 	
          <div class="p-title-pageAction">
                 <a href="', $scripturl, '?action=unread" class="button button--icon button--icon--bolt" title="', $txt['unread_since_visit'], '"><i class="fas fa-robot"></i><br><span class="button-text">', $txt['view_unread_category'], '</span></a>
                 <a href="', $scripturl, '?action=post" class="button--cta button button--icon button--icon--write" title="', $txt['new_topic'], '"><i class="fas fa-feather-alt"></i><br><span class="button-text">', $txt['new_topic'], '</span></a>
                  </div>';
		}		
	theme_linktree();
	echo '
			</div><!-- #inner_section -->
		</div><!-- #upper_section -->';
      if (!empty($settings['mobilortareklam_onoff']))
    {
		echo '
		<div class="orta_reklam">
		<a href="'. $settings['mobilortareklam_link']. '" target="_blank"><img src="'. $settings['mobilortareklam_resim']. '" alt="', $txt['mobilortareklam'], '"></a></div>';
    }
	// The main content should go here.
	echo '
		<div id="content_section">
			<div id="main_content_section">';
}

/**
 * The stuff shown immediately below the main content, including the footer
 */
function template_body_below()
{
	 global $context, $txt, $scripturl, $modSettings, $settings;

	echo '
			</div><!-- #main_content_section -->
		</div><!-- #content_section -->
	</div><!-- #wrapper -->	
</div><!-- #footerfix -->';
	// Show the footer with copyright, terms and help links.
	  global $context, $txt, $scripturl, $settings;
	 if (!empty($settings['mobilalt_onoff']))
    {
		echo ' <div class="orta1_reklam">
		<a href="'. $settings['mobilalt_link']. '" target="_blank"><img src="'. $settings['mobilalt_resim']. '" alt="', $txt['mobilreklamalt'], '"></a></div>';
    }	
	echo '
	',bildiri_block(), '
	<div class="footer">	
     <svg viewBox="0 0 120 28">
     <defs> 
      <mask id="xxx">
       <circle cx="7" cy="12" r="40" fill="#fff" />
       </mask>  
      <filter id="goo">
      <feGaussianBlur in="SourceGraphic" stdDeviation="2" result="blur" />
      <feBlend in="SourceGraphic" in2="goo" />
  	</filter>
    <path id="wave" d="M 0,10 C 30,10 30,15 60,15 90,15 90,10 120,10 150,10 150,15 180,15 210,15 210,10 240,10 v 28 h -240 z" />
    </defs> 
    <use id="wave3" class="wave" xlink:href="#wave" x="0" y="-2" ></use> 
    <use id="wave2" class="wave" xlink:href="#wave" x="0" y="0" ></use>
    <circle class="drop drop1" cx="20" cy="2" r="1.8"  />
    <circle class="drop drop2" cx="25" cy="2.5" r="1.5"  />
    <circle class="drop drop3" cx="16" cy="2.8" r="1.2"  />
    <use id="wave1" class="wave" xlink:href="#wave" x="0" y="1" />
    </svg>
		</div>';
	   if (!empty($settings['footer_sosyalonof']))
         {
		echo '
	    <div class="replikatarz">
	    <div class="replikatarz1"><i class="fa-solid fa-user-secret"></i>
	      Footer menü
	    </div>
	    <div class="replikatarz2"><i class="fa-light fa-address-card"></i><a style="text-decoration: none;color: #f2f2f2;font-size: 18px;padding: 1px;text-align: center;border-width: 1px;font-family: Times New Roman, Arial, Helvatica; " target="_blank" href="'. $settings['foter_link']. '">'. $txt['Hakkımızda'].'</a>
	    </div>
	    <div class="replikatarz3"><i class="fa-light fa-address-book"></i><a style="text-decoration: none;color: #f2f2f2;font-size: 18px;padding: 1px;text-align: center;border-width: 1px;font-family: Times New Roman, Arial, Helvatica; " target="_blank" href="'. $settings['foter_link1']. '">'. $txt['Bize_ulas'].'</a>
	    </div>
	    <div class="replikatarz4"><i class="fas fa-user-tie"></i><a style="text-decoration: none;color: #f2f2f2;font-size: 18px;padding: 1px;text-align: center;border-width: 1px;font-family: Times New Roman, Arial, Helvatica; " target="_blank" href="'. $settings['foter_link2']. '">'. $txt['Dost_Site'].'</a>
	    </div>	       
	    <div class="replikatarz5"><i class="fas fa-users-cog"></i><a style="text-decoration: none;color: #f2f2f2;font-size: 18px;padding: 1px;text-align: center;border-width: 1px;font-family: Times New Roman, Arial, Helvatica; " target="_blank" href="'. $settings['foter_link3']. '">'. $txt['hizmetlerimiz'].'</a>
		<div class="footer-social-links"> <svg class="footer-social-amoeba-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 236 54">
            <path class="footer-social-amoeba-path" d="M223.06,43.32c-.77-7.2,1.87-28.47-20-32.53C187.78,8,180.41,18,178.32,20.7s-5.63,10.1-4.07,16.7-.13,15.23-4.06,15.91-8.75-2.9-6.89-7S167.41,36,167.15,33a18.93,18.93,0,0,0-2.64-8.53c-3.44-5.5-8-11.19-19.12-11.19a21.64,21.64,0,0,0-18.31,9.18c-2.08,2.7-5.66,9.6-4.07,16.69s.64,14.32-6.11,13.9S108.35,46.5,112,36.54s-1.89-21.24-4-23.94S96.34,0,85.23,0,57.46,8.84,56.49,24.56s6.92,20.79,7,24.59c.07,2.75-6.43,4.16-12.92,2.38s-4-10.75-3.46-12.38c1.85-6.6-2-14-4.08-16.69a21.62,21.62,0,0,0-18.3-9.18C13.62,13.28,9.06,19,5.62,24.47A18.81,18.81,0,0,0,3,33a21.85,21.85,0,0,0,1.58,9.08,16.58,16.58,0,0,1,1.06,5A6.75,6.75,0,0,1,0,54H236C235.47,54,223.83,50.52,223.06,43.32Z"></path>
          </svg>		
          <a class="footer-social-link linkedin" href="'. $settings['linkedin_adresin']. '" target="_blank">
            <span class="hidden-link-text">Linkedin</span>
            <svg class="footer-social-icon-svg" xmlns="http://www.w3.org/2000/svg"
              viewBox="0 0 30 30">
              <path class="footer-social-icon-path" d="M9,25H4V10h5V25z M6.501,8C5.118,8,4,6.879,4,5.499S5.12,3,6.501,3C7.879,3,9,4.121,9,5.499C9,6.879,7.879,8,6.501,8z M27,25h-4.807v-7.3c0-1.741-0.033-3.98-2.499-3.98c-2.503,0-2.888,1.896-2.888,3.854V25H12V9.989h4.614v2.051h0.065 c0.642-1.18,2.211-2.424,4.551-2.424c4.87,0,5.77,3.109,5.77,7.151C27,16.767,27,25,27,25z"></path>
            </svg>
          </a>
          <a class="footer-social-link twitter" href="'. $settings['twitter_adresin']. '" target="_blank">
            <span class="hidden-link-text">Twitter</span>
            <svg class="footer-social-icon-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 26 26">
              <path class="footer-social-icon-path" d="M 25.855469 5.574219 C 24.914063 5.992188 23.902344 6.273438 22.839844 6.402344 C 23.921875 5.75 24.757813 4.722656 25.148438 3.496094 C 24.132813 4.097656 23.007813 4.535156 21.8125 4.769531 C 20.855469 3.75 19.492188 3.113281 17.980469 3.113281 C 15.082031 3.113281 12.730469 5.464844 12.730469 8.363281 C 12.730469 8.773438 12.777344 9.175781 12.867188 9.558594 C 8.503906 9.339844 4.636719 7.246094 2.046875 4.070313 C 1.59375 4.847656 1.335938 5.75 1.335938 6.714844 C 1.335938 8.535156 2.261719 10.140625 3.671875 11.082031 C 2.808594 11.054688 2 10.820313 1.292969 10.425781 C 1.292969 10.449219 1.292969 10.46875 1.292969 10.492188 C 1.292969 13.035156 3.101563 15.15625 5.503906 15.640625 C 5.0625 15.761719 4.601563 15.824219 4.121094 15.824219 C 3.78125 15.824219 3.453125 15.792969 3.132813 15.730469 C 3.800781 17.8125 5.738281 19.335938 8.035156 19.375 C 6.242188 20.785156 3.976563 21.621094 1.515625 21.621094 C 1.089844 21.621094 0.675781 21.597656 0.265625 21.550781 C 2.585938 23.039063 5.347656 23.90625 8.3125 23.90625 C 17.96875 23.90625 23.25 15.90625 23.25 8.972656 C 23.25 8.742188 23.246094 8.515625 23.234375 8.289063 C 24.261719 7.554688 25.152344 6.628906 25.855469 5.574219 "></path>
            </svg>
          </a>
          <a class="footer-social-link youtube" href="'. $settings['youtube_adresin']. '" target="_blank">
            <span class="hidden-link-text">Youtube</span>
            <svg class="footer-social-icon-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 30 30">
              <path class="footer-social-icon-path" d="M 15 4 C 10.814 4 5.3808594 5.0488281 5.3808594 5.0488281 L 5.3671875 5.0644531 C 3.4606632 5.3693645 2 7.0076245 2 9 L 2 15 L 2 15.001953 L 2 21 L 2 21.001953 A 4 4 0 0 0 5.3769531 24.945312 L 5.3808594 24.951172 C 5.3808594 24.951172 10.814 26.001953 15 26.001953 C 19.186 26.001953 24.619141 24.951172 24.619141 24.951172 L 24.621094 24.949219 A 4 4 0 0 0 28 21.001953 L 28 21 L 28 15.001953 L 28 15 L 28 9 A 4 4 0 0 0 24.623047 5.0546875 L 24.619141 5.0488281 C 24.619141 5.0488281 19.186 4 15 4 z M 12 10.398438 L 20 15 L 12 19.601562 L 12 10.398438 z"></path>
            </svg>
          </a>
          <a class="footer-social-link github" href="'. $settings['github_adresin']. '" target="_blank">
            <span class="hidden-link-text">Github</span>
            <svg class="footer-social-icon-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32">
              <path class="footer-social-icon-path" d="M 16 4 C 9.371094 4 4 9.371094 4 16 C 4 21.300781 7.4375 25.800781 12.207031 27.386719 C 12.808594 27.496094 13.027344 27.128906 13.027344 26.808594 C 13.027344 26.523438 13.015625 25.769531 13.011719 24.769531 C 9.671875 25.492188 8.96875 23.160156 8.96875 23.160156 C 8.421875 21.773438 7.636719 21.402344 7.636719 21.402344 C 6.546875 20.660156 7.71875 20.675781 7.71875 20.675781 C 8.921875 20.761719 9.554688 21.910156 9.554688 21.910156 C 10.625 23.746094 12.363281 23.214844 13.046875 22.910156 C 13.15625 22.132813 13.46875 21.605469 13.808594 21.304688 C 11.144531 21.003906 8.34375 19.972656 8.34375 15.375 C 8.34375 14.0625 8.8125 12.992188 9.578125 12.152344 C 9.457031 11.851563 9.042969 10.628906 9.695313 8.976563 C 9.695313 8.976563 10.703125 8.65625 12.996094 10.207031 C 13.953125 9.941406 14.980469 9.808594 16 9.804688 C 17.019531 9.808594 18.046875 9.941406 19.003906 10.207031 C 21.296875 8.65625 22.300781 8.976563 22.300781 8.976563 C 22.957031 10.628906 22.546875 11.851563 22.421875 12.152344 C 23.191406 12.992188 23.652344 14.0625 23.652344 15.375 C 23.652344 19.984375 20.847656 20.996094 18.175781 21.296875 C 18.605469 21.664063 18.988281 22.398438 18.988281 23.515625 C 18.988281 25.121094 18.976563 26.414063 18.976563 26.808594 C 18.976563 27.128906 19.191406 27.503906 19.800781 27.386719 C 24.566406 25.796875 28 21.300781 28 16 C 28 9.371094 22.628906 4 16 4 Z "></path>
            </svg>
          </a></div></div></div>';
		  }
		echo '
	      <div id="footer">';
		   if (!empty($settings['footer_sosyalonof']))
         {
		echo '
	<div class="container-fluid footer-back m-0 pb-1 ">
		<div class="media mx-4 bg-opacity p-2 rounded mb-1">
			<span class="fas fa-user-shield f-3x text-warning mr-2 bg-opacity px-2 rounded"></span>
				<div class="media-body f-lg2">
					<h5 class="mt-0 bold text-warning">'. $txt['uyar'].'</h5>'. $settings['footer_uyarilar']. '
				</div>
		</div>
		<div class="media mx-4 bg-opacity p-2 rounded">
			<span class="fas fa-bullhorn f-3x text-info mr-2 bg-opacity px-2 pt-1 rounded"></span>
				<div class="media-body f-lg2">
					<h5 class="mt-0bold text-info">'. $txt['bilgi'].'</h5>'. $settings['footer_bilgilendirme']. '
				</div></div></div>
	       <div class="inner_wrap"></div>';
		}
	// There is now a global "Go to top" link at the right.
	echo '
		<ul>
			<li class="floatright"><a href="https://www.replikacep.com/" target="_blank"><i class="far fa-copyright"></i> Replikacep | </a><a href="', $scripturl, '?action=help">', $txt['help'], '</a> ', (!empty($modSettings['requireAgreement'])) ? '| <a href="' . $scripturl . '?action=help;sa=rules">' . $txt['terms_and_rules'] . '</a>' : '', ' | <a href="#top_section">', $txt['go_up'], ' &#9650;</a></li>
			<li class="copyright">', theme_copyright(), '</li>
		</ul>';
	// Show the load time?
	if ($context['show_load_time'])
		echo '
		<p>', sprintf($txt['page_created_full'], $context['load_time'], $context['load_queries']), '</p>';

	echo '
		</div>
	<!-- #footer -->
    <a href="#" class="scroll-to-top hidden-print"><i class="fa fa-chevron-up fa-lg"></i></a>
    <a href="', $scripturl, '" class="link-to-home"><i class="fa fa-home fa-lg"></i></a>';
	
	if (!empty($settings['mobile_navigation_onoff']))
    {
	echo '
     <div class="mobile-navigation-bar">
     <div class="focus-width">
     <ul class="mobile-navigation-bar__list">
     <li class="mobile-navigation-bar--forums">
     <a href="', $scripturl, '" style="text-decoration: none;">
     <span class="mobile-navigation-bar__icon"><i class="far fa-comments" aria-hidden="true"></i></span>
     <span class="mobile-navigation-bar__text">', $txt['search_entireforum'], '</span>
     </a>
     </li>';
	 if($context['user']['is_guest'] ) {
     echo'
	<li class="mobile-navigation-bar--login">
    <a href="', $scripturl, '?action=login" class="', $context['current_action'] == 'login' ? 'active' : 'open','" onclick="return reqOverlayDiv(this.href, ' . JavaScriptEscape($txt['login']) . ', \'login\');" style="text-decoration: none;">
    <span class="mobile-navigation-bar__icon"><i class="fas fa-sign-in-alt" aria-hidden="true" style="margin-left: 8px;"></i></span>
    <span class="mobile-navigation-bar__text">', $txt['login'], '</span>
    </a>	
    </li>';
	}
	if ($context['user']['is_logged']) { 
     echo'
    <li class="mobile-navigation-bar--login">
    <a href="', $scripturl, '?action=post" style="text-decoration: none;">
    <span class="mobile-navigation-bar__icon"><i class="fas fa-feather-alt" aria-hidden="true" style="margin-left: 8px;"></i></span>
    <span class="mobile-navigation-bar__text">', $txt['new_topic'], '</span>
    </a>
    </li>';
	}
	if($context['user']['is_guest'] ) {
	echo'
    <li class="mobile-navigation-bar--register">
    <a href="', $scripturl, '?action=signup" data-xf-click="overlay" style="text-decoration: none;">
   <span class="mobile-navigation-bar__icon"><i class="fas fa-user-plus" aria-hidden="true" style="margin-left: 8px;"></i></span>
   <span class="mobile-navigation-bar__text">', $txt['register'], '</span>
    </a>
    </li>';
	}
	if ($context['user']['is_logged']) { 
	echo'
    <li class="mobile-navigation-bar--register">
    <a href="', $scripturl, '?action=profile" data-xf-click="overlay" style="text-decoration: none;">
   <span class="mobile-navigation-bar__icon"><i class="fas fa-user-alt" aria-hidden="true" style="margin-left: 8px;"></i></span>
   <span class="mobile-navigation-bar__text">', $txt['profile'], '</span>
    </a>
    </li>';
	}
	echo'
    <li class="mobile-navigation-bar--search">
    <a href="', $scripturl, '?action=search" style="text-decoration: none;">
    <span class="mobile-navigation-bar__icon"><i class="fas fa-search" aria-hidden="true"></i></span>
    <span class="mobile-navigation-bar__text">', $txt['search'], '</span>
    </a>
    </li>
    </ul>
    </div>
    </div>';	
}
}

/**
 * This shows any deferred JavaScript and closes out the HTML
 */
function template_html_below()
{
global $settings;

if(empty($settings['disable_user_variant'])){
echo'<svg class="grovmenu">
    <defs>
    <filter id="filt"><feGaussianBlur in="SourceGraphic" result="blur" stdDeviation="10" />
      <feColorMatrix in="SourceGraphic" type="matrix" values=".25 .5 .25 0 0
                                                              .25 .5 .25 0 0
                                                              .25 .5 .25 0 0
                                                              0 0 0 1 0"/>
    <feBlend in2="filt" in="SourceGraphic" result="mix" /></filter></defs>
   </svg>
  <div class="wrap">
 <input type="checkbox" id="checking" style="display:none;">
 <a class="blob" href="?variant=default"><span class="main_icons current_theme"></span></a>
 <a class="blob" href="?variant=blue"><span class="main_icons current_theme"></span></a>
 <a class="blob" href="?variant=black"><span class="main_icons current_theme"></span></a>
 <a class="blob" href="?variant=burgundy"><span class="main_icons current_theme"></span></a>
 <a class="blob" href="?variant=yellow"><span class="main_icons current_theme"></span></a>
 <label class="blob" for="checking"> 
  <span class="bar"></span> 
  <span class="bar"></span> 
  <span class="bar"></span></label>
 </div>';
}	
	// Load in any javascipt that could be deferred to the end of the page
	template_javascript(true);
        echo ' <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js"></script>
             <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js"></script>';
			 
	global $settings, $txt;
	if (!empty($settings['yanreklam_onoff']))
		 {
		  echo '
		<div class="sol_reklam"><a href="'. $settings['yanreklam_adres']. '" target="_blank"><img src="'. $settings['yanreklam_resimadres'].'" alt="', $txt['solreklamalanı'], '"></a>
		 </div>
		 <div class="sag_reklam"><a href="'. $settings['yanreklam_adres1']. '" target="_blank"><img src=" '. $settings['yanreklam_resimadres1'].'" alt="', $txt['sagreklamalanı'], '"></a>
		</div>';
		 }	
	  
echo '
</body>
</html>';
}

/**
 * Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
 *
 * @param bool $force_show Whether to force showing it even if settings say otherwise
 */
function theme_linktree($force_show = false)
{
	global $context, $shown_linktree, $scripturl, $txt;
	
	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	echo '
				<div class="navigate_section">
					<ul>';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
						<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';

		// Don't show a separator for the first one.
		// Better here. Always points to the next level when the linktree breaks to a second line.
		// Picked a better looking HTML entity, and added support for RTL plus a span for styling.
		if ($link_num != 0)
			echo '
							<span class="dividers">', $context['right_to_left'] ? ' &#9668; ' : ' &#9658; ', '</span>';

		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'], ' ';

		// Show the link, including a URL if it should have one.
		if (isset($tree['url']))
			echo '
							<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>';
		else
			echo '
							<span>' . $tree['name'] . '</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo ' ', $tree['extra_after'];

		echo '
						</li>';
	}

	echo '
					</ul>
				</div><!-- .navigate_section -->';
				
	$shown_linktree = true;
}

/**
 * Show the menu up top. Something like [home] [help] [profile] [logout]...
 */
function template_menu()
{
	global $context;

	echo '
					<ul class="dropmenu menu_nav">';

	// Note: Menu markup has been cleaned up to remove unnecessary spans and classes.
	foreach ($context['menu_buttons'] as $act => $button)
	{
		echo '
						<li class="button_', $act, '', !empty($button['sub_buttons']) ? ' subsections"' : '"', '>
							<a', $button['active_button'] ? ' class="active"' : '', ' href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '"' : '', isset($button['onclick']) ? ' onclick="' . $button['onclick'] . '"' : '', '>
								', $button['icon'], '<span class="textmenu">', $button['title'], !empty($button['amt']) ? ' <span class="amt">' . $button['amt'] . '</span>' : '', '</span>
							</a>';

		// 2nd level menus
		if (!empty($button['sub_buttons']))
		{
			echo '
							<ul>';

			foreach ($button['sub_buttons'] as $childbutton)
			{
				echo '
								<li', !empty($childbutton['sub_buttons']) ? ' class="subsections"' : '', '>
									<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '"' : '', isset($childbutton['onclick']) ? ' onclick="' . $childbutton['onclick'] . '"' : '', '>
										', $childbutton['title'], !empty($childbutton['amt']) ? ' <span class="amt">' . $childbutton['amt'] . '</span>' : '', '
									</a>';
				// 3rd level menus :)
				if (!empty($childbutton['sub_buttons']))
				{
					echo '
									<ul>';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)
						echo '
										<li>
											<a href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '"' : '', isset($grandchildbutton['onclick']) ? ' onclick="' . $grandchildbutton['onclick'] . '"' : '', '>
												', $grandchildbutton['title'], !empty($grandchildbutton['amt']) ? ' <span class="amt">' . $grandchildbutton['amt'] . '</span>' : '', '
											</a>
										</li>';

					echo '
									</ul>';
				}

				echo '
								</li>';
			}
			echo '
							</ul>';
		}
		echo '
						</li>';
	}

	echo '
					</ul><!-- .menu_nav -->';
}

/**
 * Generate a strip of buttons.
 *
 * @param array $button_strip An array with info for displaying the strip
 * @param string $direction The direction
 * @param array $strip_options Options for the button strip
 */
function template_button_strip($button_strip, $direction = '', $strip_options = array())
{
	global $context, $txt;

	if (!is_array($strip_options))
		$strip_options = array();

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		// As of 2.1, the 'test' for each button happens while the array is being generated. The extra 'test' check here is deprecated but kept for backward compatibility (update your mods, folks!)
		if (!isset($value['test']) || !empty($context[$value['test']]))
		{
			if (!isset($value['id']))
				$value['id'] = $key;

			$button = '
				<a class="button button_strip_' . $key . (!empty($value['active']) ? ' active' : '') . (isset($value['class']) ? ' ' . $value['class'] : '') . '" ' . (!empty($value['url']) ? 'href="' . $value['url'] . '"' : '') . ' ' . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '>'.(!empty($value['icon']) ? '<span class="main_icons '.$value['icon'].'"></span>' : '').'' . $txt[$value['text']] . '</a>';

			if (!empty($value['sub_buttons']))
			{
				$button .= '
					<div class="top_menu dropmenu ' . $key . '_dropdown">
						<div class="viewport">
							<div class="overview">';
				foreach ($value['sub_buttons'] as $element)
				{
					if (isset($element['test']) && empty($context[$element['test']]))
						continue;

					$button .= '
								<a href="' . $element['url'] . '"><strong>' . $txt[$element['text']] . '</strong>';
					if (isset($txt[$element['text'] . '_desc']))
						$button .= '<br><span>' . $txt[$element['text'] . '_desc'] . '</span>';
					$button .= '</a>';
				}
				$button .= '
							</div><!-- .overview -->
						</div><!-- .viewport -->
					</div><!-- .top_menu -->';
			}

			$buttons[] = $button;
		}
	}

	// No buttons? No button strip either.
	if (empty($buttons))
		return;

	echo '
		<div class="buttonlist', !empty($direction) ? ' float' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"' : ''), '>
			', implode('', $buttons), '
		</div>';
}

/**
 * Generate a list of quickbuttons.
 *
 * @param array $list_items An array with info for displaying the strip
 * @param string $list_class Used for integration hooks and as a class name
 * @param string $output_method The output method. If 'echo', simply displays the buttons, otherwise returns the HTML for them
 * @return void|string Returns nothing unless output_method is something other than 'echo'
 */
function template_quickbuttons($list_items, $list_class = null, $output_method = 'echo')
{
	global $txt;

	// Enable manipulation with hooks
	if (!empty($list_class))
		call_integration_hook('integrate_' . $list_class . '_quickbuttons', array(&$list_items));

	// Make sure the list has at least one shown item
	foreach ($list_items as $key => $li)
	{
		// Is there a sublist, and does it have any shown items
		if ($key == 'more')
		{
			foreach ($li as $subkey => $subli)
				if (isset($subli['show']) && !$subli['show'])
					unset($list_items[$key][$subkey]);

			if (empty($list_items[$key]))
				unset($list_items[$key]);
		}
		// A normal list item
		elseif (isset($li['show']) && !$li['show'])
			unset($list_items[$key]);
	}

	// Now check if there are any items left
	if (empty($list_items))
		return;

	// Print the quickbuttons
	$output = '
		<ul class="quickbuttons' . (!empty($list_class) ? ' quickbuttons_' . $list_class : '') . '">';

	// This is used for a list item or a sublist item
	$list_item_format = function($li)
	{
		$html = '
			<li' . (!empty($li['class']) ? ' class="' . $li['class'] . '"' : '') . (!empty($li['id']) ? ' id="' . $li['id'] . '"' : '') . (!empty($li['custom']) ? ' ' . $li['custom'] : '') . '>';

		if (isset($li['content']))
			$html .= $li['content'];
		else
			$html .= '
				<a href="' . (!empty($li['href']) ? $li['href'] : 'javascript:void(0);') . '"' . (!empty($li['javascript']) ? ' ' . $li['javascript'] : '') . '>
					' . (!empty($li['icon']) ? '<span class="main_icons ' . $li['icon'] . '"></span>' : '') . (!empty($li['label']) ? $li['label'] : '') . '
				</a>';

		$html .= '
			</li>';

		return $html;
	};

	foreach ($list_items as $key => $li)
	{
		// Handle the sublist
		if ($key == 'more')
		{
			$output .= '
			<li class="post_options">
				<a href="javascript:void(0);">' . $txt['post_options'] . '</a>
				<ul>';

			foreach ($li as $subli)
				$output .= $list_item_format($subli);

			$output .= '
				</ul>
			</li>';
		}
		// Ordinary list item
		else
			$output .= $list_item_format($li);
	}

	$output .= '
		</ul><!-- .quickbuttons -->';

	// There are a few spots where the result needs to be returned
	if ($output_method == 'echo')
		echo $output;
	else
		return $output;
}

/**
 * The upper part of the maintenance warning box
 */
function template_maint_warning_above()
{
	global $txt, $context, $scripturl;

	echo '
	<div class="errorbox" id="errors">
		<dl>
			<dt>
				<strong id="error_serious">', $txt['forum_in_maintenance'], '</strong>
			</dt>
			<dd class="error" id="error_list">
				', sprintf($txt['maintenance_page'], $scripturl . '?action=admin;area=serversettings;' . $context['session_var'] . '=' . $context['session_id']), '
			</dd>
		</dl>
	</div>';
}


function bildiri_block()
{
 global $settings, $context, $scripturl;
 
 if (!empty($settings['bildiri']))
 $bildiri = '<div id="bildiri_en"><div class="md-index_wrap">
 <div class="md-index_icon">
 <div class="md-index_icon_status">
<i class="fa fa-anchor" aria-hidden="true"></i>
 </div>
 </div>
 <div class="md-index_main">'.$settings['bildiri'].'</div></div></div>';

 if (!empty($settings['bildiri']) && !empty($settings['enable_bildir']) &&  $settings['type_bildir']== 1)
 $bildiri = parse_bbc($bildiri);
 
 if (!empty($settings['bildiri']) && !empty($settings['enable_bildir']) && !$context['user']['is_guest'] && $settings['enable_bildir']== 2)
 echo $bildiri;
 elseif (!empty($settings['bildiri']) && !empty($settings['enable_bildir']) && $context['user']['is_guest'] && $settings['enable_bildir']== 1)
 echo $bildiri;
 elseif (!empty($settings['bildiri']) && !empty($settings['enable_bildir']) && $settings['enable_bildir']== 3)
 if (!empty($settings['bildiri']))
 echo $bildiri;
}

/**
 * The lower part of the maintenance warning box.
 */
function template_maint_warning_below()
{

}

?>